==> openshift-model-monitoring-5.11.1-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/AuthorizationFluentImpl.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import io.fabric8.kubernetes.api.model.SecretKeySelector;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class AuthorizationFluentImpl<A extends io.fabric8.openshift.api.model.monitoring.v1.AuthorizationFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.monitoring.v1.AuthorizationFluent<A>{
  public AuthorizationFluentImpl() {
  }
  public AuthorizationFluentImpl(io.fabric8.openshift.api.model.monitoring.v1.Authorization instance) {
    this.withCredentials(instance.getCredentials()); 
    this.withCredentialsFile(instance.getCredentialsFile()); 
    this.withType(instance.getType()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.kubernetes.api.model.SecretKeySelector credentials;
  private java.lang.String credentialsFile;
  private java.lang.String type;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public io.fabric8.kubernetes.api.model.SecretKeySelector getCredentials() {
    return this.credentials;
  }
  public A withCredentials(io.fabric8.kubernetes.api.model.SecretKeySelector credentials) {
    this.credentials=credentials; return (A) this;
  }
  public java.lang.Boolean hasCredentials() {
    return this.credentials != null;
  }
  public A withNewCredentials(java.lang.String key,java.lang.String name,java.lang.Boolean optional) {
    return (A)withCredentials(new SecretKeySelector(key, name, optional));
  }
  public java.lang.String getCredentialsFile() {
    return this.credentialsFile;
  }
  public A withCredentialsFile(java.lang.String credentialsFile) {
    this.credentialsFile=credentialsFile; return (A) this;
  }
  public java.lang.Boolean hasCredentialsFile() {
    return this.credentialsFile != null;
  }
  
  /**
   * Method is deprecated. use withCredentialsFile instead.
   */
  @java.lang.Deprecated
  public A withNewCredentialsFile(java.lang.String arg0) {
    return (A)withCredentialsFile(new String(arg0));
  }
  public java.lang.String getType() {
    return this.type;
  }
  public A withType(java.lang.String type) {
    this.type=type; return (A) this;
  }
  public java.lang.Boolean hasType() {
    return this.type != null;
  }
  
  /**
   * Method is deprecated. use withType instead.
   */
  @java.lang.Deprecated
  public A withNewType(java.lang.String arg0) {
    return (A)withType(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    AuthorizationFluentImpl that = (AuthorizationFluentImpl) o;
    if (credentials != null ? !credentials.equals(that.credentials) :that.credentials != null) return false;
    if (credentialsFile != null ? !credentialsFile.equals(that.credentialsFile) :that.credentialsFile != null) return false;
    if (type != null ? !type.equals(that.type) :that.type != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(credentials,  credentialsFile,  type,  additionalProperties,  super.hashCode());
  }
  
}

==> openshift-model-monitoring-5.12.2-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/AuthorizationFluentImpl.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import io.fabric8.kubernetes.api.model.SecretKeySelector;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class AuthorizationFluentImpl<A extends io.fabric8.openshift.api.model.monitoring.v1.AuthorizationFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.monitoring.v1.AuthorizationFluent<A>{
  public AuthorizationFluentImpl() {
  }
  public AuthorizationFluentImpl(io.fabric8.openshift.api.model.monitoring.v1.Authorization instance) {
    this.withCredentials(instance.getCredentials()); 
    this.withCredentialsFile(instance.getCredentialsFile()); 
    this.withType(instance.getType()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.kubernetes.api.model.SecretKeySelector credentials;
  private java.lang.String credentialsFile;
  private java.lang.String type;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public io.fabric8.kubernetes.api.model.SecretKeySelector getCredentials() {
    return this.credentials;
  }
  public A withCredentials(io.fabric8.kubernetes.api.model.SecretKeySelector credentials) {
    this.credentials=credentials; return (A) this;
  }
  public java.lang.Boolean hasCredentials() {
    return this.credentials != null;
  }
  public A withNewCredentials(java.lang.String key,java.lang.String name,java.lang.Boolean optional) {
    return (A)withCredentials(new SecretKeySelector(key, name, optional));
  }
  public java.lang.String getCredentialsFile() {
    return this.credentialsFile;
  }
  public A withCredentialsFile(java.lang.String credentialsFile) {
    this.credentialsFile=credentialsFile; return (A) this;
  }
  public java.lang.Boolean hasCredentialsFile() {
    return this.credentialsFile != null;
  }
  
  /**
   * Method is deprecated. use withCredentialsFile instead.
   */
  @java.lang.Deprecated
  public A withNewCredentialsFile(java.lang.String arg0) {
    return (A)withCredentialsFile(new String(arg0));
  }
  public java.lang.String getType() {
    return this.type;
  }
  public A withType(java.lang.String type) {
    this.type=type; return (A) this;
  }
  public java.lang.Boolean hasType() {
    return this.type != null;
  }
  
  /**
   * Method is deprecated. use withType instead.
   */
  @java.lang.Deprecated
  public A withNewType(java.lang.String arg0) {
    return (A)withType(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    AuthorizationFluentImpl that = (AuthorizationFluentImpl) o;
    if (credentials != null ? !credentials.equals(that.credentials) :that.credentials != null) return false;
    if (credentialsFile != null ? !credentialsFile.equals(that.credentialsFile) :that.credentialsFile != null) return false;
    if (type != null ? !type.equals(that.type) :that.type != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(credentials,  credentialsFile,  type,  additionalProperties,  super.hashCode());
  }
  
}
